maxHeightFraction property
Maximum height as a fraction of screen height (0.0-1.0). Defaults to 0.6.
Implementation
final double? maxHeightFraction;
Maximum height as a fraction of screen height (0.0-1.0). Defaults to 0.6.
final double? maxHeightFraction;