FieldWidth class

Controls the field width behavior for MultiSelectField.

Constructors

FieldWidth(double? value)
const
FieldWidth.fixed(double width)
Field uses a fixed width in pixels.
const
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fitContent → const FieldWidth
Field shrinks to fit its content.