isFirstSelectedIn method

bool isFirstSelectedIn(
  1. List<Choice<T>> selectedChoice
)

Whether this choice occupies the first slot in selectedChoice.

Used by the menu list to attach the auto-scroll target key only to the first selected entry.

Implementation

bool isFirstSelectedIn(List<Choice<T>> selectedChoice) {
  return isSelectedIn(selectedChoice) && selectedChoice.indexOf(this) == 0;
}