MultiSelectLabel class
Reusable label widget for MultiSelectField variants.
Centralizes how a label string is rendered based on a LabelType preset.
Use it as the standard building block when supplying a labelBuilder:
MultiSelectField<Foo>(
label: 'Categories',
labelBuilder: (label) => MultiSelectLabel(
label: label,
type: LabelType.wrap,
maxLines: 2,
style: Theme.of(context).textTheme.titleSmall,
),
data: () => choices,
)
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- MultiSelectLabel
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- label → String
-
Text to display.
final
- maxLines → int
-
Max lines used when type is LabelType.wrap. Defaults to 2.
Ignored for other types.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → TextStyle?
-
Optional text style. Falls back to the ambient DefaultTextStyle.
final
- type → LabelType
-
Rendering preset. See LabelType.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited