SelectionContent<T> class
Shared selection content widget used by all MultiSelectField variants.
Renders a list of selectable items with support for:
- Single or multi selection (checkbox/radio)
- Group titles
- Select all option
- Custom content override via menuContent
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- SelectionContent
Constructors
-
SelectionContent({Key? key, List<
Choice< data()?, required bool selectAllOption, required bool singleSelection, required bool selectAllActive, required List<T> >Choice< selectedChoices, TextStyle? titleMenuStyle, TextStyle? itemMenuStyle, EdgeInsetsGeometry? titleMenuPadding, required void onToggleSelection(Choice<T> >T> ), required VoidCallback onToggleSelectAll, required bool isSelected(Choice<T> )}) -
const
Properties
-
data
→ List<
Choice< Function()?T> > -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
isSelected
→ bool Function(Choice<
T> ) -
final
- itemMenuStyle → TextStyle?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
final
- onToggleSelectAll → VoidCallback
-
final
-
onToggleSelection
→ void Function(Choice<
T> ) -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectAllActive → bool
-
final
- selectAllOption → bool
-
final
-
selectedChoices
→ List<
Choice< T> > -
final
- singleSelection → bool
-
final
- titleMenuPadding → EdgeInsetsGeometry?
-
final
- titleMenuStyle → TextStyle?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited